/**
 * Copyright (C) 2007-2015 Lawrence Murray
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * @author Lawrence Murray <lawrence@indii.org>
 * $Rev: 363 $
 * $Date: 2012-01-22 18:45:43 +0800 (Sun, 22 Jan 2012) $
 */
#ifndef INDII_IMAGES_INDII_HPP
#define INDII_IMAGES_INDII_HPP

#include <wx/wxprec.h>
#ifndef WX_PRECOMP
#include <wx/wx.h>
#endif

extern void indii_initialize_images(void);
extern wxBitmap* indii_retinize(wxBitmap* bmp);
extern void indii_scale_images(const double contentScale = 1.0);

extern wxBitmap *_img_indii_stipple;
extern wxBitmap *_img_indii_splash;
extern wxBitmap *_img_indii_splash_32;
extern wxBitmap *_img_indii_splash_64;

#endif
